# Class Hierarchy

- `collections.abc.MutableMapping`
  - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data` - MagnetiCalc_Data class.
- `magneticalc.API.API` - API class.
- `magneticalc.Assert_Dialog.Assert_Dialog` - Assert_Dialog class.
- `magneticalc.Backend_CUDA.Backend_CUDA` - Implements the Biot-Savart law for calculating the magnetic flux density (B-field) and vector potential (A-field). Backend: JIT + CUDA.
- `magneticalc.Backend_JIT.Backend_JIT` - Implements the Biot-Savart law for calculating the magnetic flux density (B-field) and vector potential (A-field). Backend: JIT.
- `magneticalc.Config.Config` - Config class.
  - `magneticalc.Project.Project` - Project class.
- `magneticalc.Config_Group.Config_Collection` - Config_Collection class.
- `magneticalc.Constants.Constants` - Constants class.
- `magneticalc.Constraint.Constraint` - Constraint class.
- `magneticalc.Debug.Debug` - Debug class.
- `magneticalc.Format.Format` - Format class.
- `magneticalc.Menu.Menu` - Menu class.
- `magneticalc.Metric_Presets.Metric_Presets` - Metric_Presets class.
- `magneticalc.Model.Model` - Model class.
- `magneticalc.ModelAccess.ModelAccess` - Model access class.
- `magneticalc.Perspective_Presets.Perspective_Presets` - Perspective_Presets class.
- `magneticalc.QCheckboxConfig.QCheckboxConfig` - QCheckboxConfig class.
- `magneticalc.QtWidgets2.QLayouted.QLayouted` - QLayouted class.
  - `magneticalc.QtWidgets2.QDialog2.QDialog2` - QDialog2 class.
    - `magneticalc.About_Dialog.About_Dialog` - About_Dialog class.
    - `magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog` - CheckForUpdates_Dialog class.
    - `magneticalc.Constraint_Editor.Constraint_Editor` - Constraint_Editor class.
    - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog` - ExportContainer_Dialog class.
    - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog` - OverridePadding_Dialog class.
    - `magneticalc.QMessageBox2.QMessageBox2` - QMessageBox2 class.
    - `magneticalc.Usage_Dialog.Usage_Dialog` - Usage_Dialog class.
  - `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2` - QGroupBox2 class.
    - `magneticalc.Display_Widget.Display_Widget` - Display_Widget class.
    - `magneticalc.Field_Widget.Field_Widget` - Field_Widget class.
    - `magneticalc.Metric_Widget.Metric_Widget` - Metric_Widget class.
    - `magneticalc.Parameters_Widget.Parameters_Widget` - Parameters_Widget class.
    - `magneticalc.Perspective_Widget.Perspective_Widget` - Perspective_Widget class.
    - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget` - SamplingVolume_Widget class.
    - `magneticalc.Wire_Widget.Wire_Widget` - Wire_Widget class.
- `magneticalc.QtWidgets2.QSaveAction.QSaveAction` - QSaveAction class.
- `magneticalc.Statusbar.Statusbar` - Statusbar class.
- `magneticalc.Theme.Theme` - Theme class.
- `magneticalc.Version.Version` - Version class.
- `magneticalc.Wire_Presets.Wire_Presets` - Wire_Presets class.
- `object`
  - `magneticalc.ConditionalDecorator.ConditionalDecorator` - ConditionalDecorator class.
  - `magneticalc.Validatable.Validatable` - Validatable class.
    - `magneticalc.Field.Field` - Field class.
    - `magneticalc.Metric.Metric` - Provides different metrics, used for mapping some field vector properties to some color and alpha range.
    - `magneticalc.Parameters.Parameters` - Parameters class.
    - `magneticalc.SamplingVolume.SamplingVolume` - Sampling volume class.
    - `magneticalc.Wire.Wire` - Wire class.
- `PyQt5.QtCore.QAbstractTableModel`
  - `magneticalc.QTableView2.TableModel` - TableModel class.
- `PyQt5.QtCore.QThread`
  - `magneticalc.CalculationThread.CalculationThread` - CalculationThread class. The calculation thread implements an offloaded pipeline of subsequent calculation subtasks. The pipeline may be interrupted at (almost) any time, thereby exiting this thread.
- `PyQt5.QtWidgets.QDialog`
  - `magneticalc.QtWidgets2.QDialog2.QDialog2` - QDialog2 class.
    - `magneticalc.About_Dialog.About_Dialog` - About_Dialog class.
    - `magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog` - CheckForUpdates_Dialog class.
    - `magneticalc.Constraint_Editor.Constraint_Editor` - Constraint_Editor class.
    - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog` - ExportContainer_Dialog class.
    - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog` - OverridePadding_Dialog class.
    - `magneticalc.QMessageBox2.QMessageBox2` - QMessageBox2 class.
    - `magneticalc.Usage_Dialog.Usage_Dialog` - Usage_Dialog class.
- `PyQt5.QtWidgets.QDoubleSpinBox`
  - `magneticalc.QtWidgets2.QDoubleSpinBox2.QDoubleSpinBox2` - QDoubleSpinBox2 class.
- `PyQt5.QtWidgets.QFrame`
  - `magneticalc.QtWidgets2.QHLine.QHLine` - QHLine class.
- `PyQt5.QtWidgets.QGroupBox`
  - `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2` - QGroupBox2 class.
    - `magneticalc.Display_Widget.Display_Widget` - Display_Widget class.
    - `magneticalc.Field_Widget.Field_Widget` - Field_Widget class.
    - `magneticalc.Metric_Widget.Metric_Widget` - Metric_Widget class.
    - `magneticalc.Parameters_Widget.Parameters_Widget` - Parameters_Widget class.
    - `magneticalc.Perspective_Widget.Perspective_Widget` - Perspective_Widget class.
    - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget` - SamplingVolume_Widget class.
    - `magneticalc.Wire_Widget.Wire_Widget` - Wire_Widget class.
- `PyQt5.QtWidgets.QHBoxLayout`
  - `magneticalc.QtWidgets2.QButtons.QButtons` - QButtons class.
  - `magneticalc.QtWidgets2.QHBoxLayout2.QHBoxLayout2` - QHBoxLayout2 class.
  - `magneticalc.QtWidgets2.QIconLabel.QIconLabel` - QIconLabel class.
- `PyQt5.QtWidgets.QLabel`
  - `magneticalc.QtWidgets2.QLabel2.QLabel2` - QLabel2 class.
- `PyQt5.QtWidgets.QMainWindow`
  - `magneticalc.GUI.GUI` - GUI class.
- `PyQt5.QtWidgets.QMenu`
  - `magneticalc.File_Menu.File_Menu` - File_Menu class.
  - `magneticalc.Help_Menu.Help_Menu` - Help_Menu class.
  - `magneticalc.Options_Menu.Options_Menu` - Options_Menu class.
  - `magneticalc.View_Menu.View_Menu` - View_Menu class.
  - `magneticalc.Wire_Menu.Wire_Menu` - Wire_Menu class.
- `PyQt5.QtWidgets.QPushButton`
  - `magneticalc.QtWidgets2.QPushButton2.QPushButton2` - QPushButton2 class.
- `PyQt5.QtWidgets.QScrollArea`
  - `magneticalc.SidebarLeft.SidebarLeft` - SidebarLeft class.
  - `magneticalc.SidebarRight.SidebarRight` - SidebarRight class.
- `PyQt5.QtWidgets.QSlider`
  - `magneticalc.QtWidgets2.QSliderFloat.QSliderFloat` - QSliderFloat class.
- `PyQt5.QtWidgets.QSpinBox`
  - `magneticalc.QtWidgets2.QSpinBox2.QSpinBox2` - QSpinBox2 class.
- `PyQt5.QtWidgets.QTableView`
  - `magneticalc.QTableView2.QTableView2` - QTableView2 class.
- `PyQt5.QtWidgets.QTextBrowser`
  - `magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2` - QTextBrowser2 class.
- `vispy.scene.SceneCanvas`
  - `magneticalc.VisPyCanvas.VisPyCanvas` - VisPyCanvas class.